@@ -6,9 +6,12 @@ __appname__ = "dialcentral"
 __description__ = "Simple interface to Google's GrandCentral(tm) service"
 __author__ = "Eric Warnke"
 __email__ = "ericew@gmail.com"
-__version__ = "0.8.0"
-__build__ = 9
+__version__ = "0.8.1"
+__build__ = 0
 __changelog__ = '''\
+0.8.1 - "Two Beers"
+ * Thumb scrollbars ( Kudos Khertan )
+
 0.8.0 - "Spit and polish"
  * Addressbook support
  * threaded networking for better interactivity
